diff src/eval.c @ 23495:1f85acfb23cd v8.2.2290

patch 8.2.2290: Vim9: unlet of global variable cannot be compiled Commit: https://github.com/vim/vim/commit/2ef951dd31505874ae9ac35a18513ef34ae0ea3e Author: Bram Moolenaar <Bram@vim.org> Date: Sun Jan 3 20:55:26 2021 +0100 patch 8.2.2290: Vim9: unlet of global variable cannot be compiled Problem: Vim9: unlet of global variable cannot be compiled. Solution: Skip over variables that might be defined later. Give an error if a subscript is found. (closes #7585)
author Bram Moolenaar <Bram@vim.org>
date Sun, 03 Jan 2021 21:00:05 +0100
parents f8382c4e6551
children fe868a6d2e0a
line wrap: on
line diff
--- a/src/eval.c
+++ b/src/eval.c
@@ -813,9 +813,9 @@ get_lval(
     // Clear everything in "lp".
     CLEAR_POINTER(lp);
 
-    if (skip)
+    if (skip || (flags & GLV_COMPILING))
     {
 	// When skipping just find the end of the name.
 	lp->ll_name = name;
 	lp->ll_name_end = find_name_end(name, NULL, NULL,
 						      FNE_INCL_BR | fne_flags);
@@ -813,9 +813,9 @@ get_lval(
     {
-	// When skipping just find the end of the name.
+	// When skipping or compiling just find the end of the name.
 	lp->ll_name = name;
 	lp->ll_name_end = find_name_end(name, NULL, NULL,